<!DOCTYPE html>
<html lang="en">
<head>
    <title>Gold Investment in India</title>
    <meta charset="utf-8">
    <meta name="viewport" content="width=device-width, height=device-height, initial-scale=1.0">
    <meta http-equiv="X-UA-Compatible" content="IE=edge">
    <link rel="icon" href="images/favicon.ico" type="image/x-icon">
    <?php include('head-link.php');?>
    <style>
        .container {
            margin-top: 50px;
        }
        canvas {
            max-width: 100%;
            height: auto;
        }
    </style>
    <!-- Include Chart.js library and Date Adapter -->
    <script src="https://cdn.jsdelivr.net/npm/chart.js"></script>
    <script src="https://cdn.jsdelivr.net/npm/chartjs-adapter-date-fns@3.0.0"></script>
    <script src="https://cdn.jsdelivr.net/npm/chartjs-plugin-datalabels@2.0.0"></script>
</head>
<body>
    <div class="preloader">
        <div class="preloader-body">
            <div class="loader">
                <div></div>
                <div></div>
                <div></div>
                <div></div>
                <div></div>
                <div></div>
                <div></div>
                <div></div>
                <div></div>
            </div>
            <p>Loading...</p>
        </div>
    </div>
    <div class="page">
        <?php include("header.php");?>
        <div class="container" style="padding:50px;margin-top:40px">
            <h2 class="text-center">Gold Rate in INR from 2000 to 2024</h2>
            <canvas id="goldRateChart"></canvas>
        </div>
        <?php include('footer.php');?>
    </div>
    <script>
    document.addEventListener('DOMContentLoaded', function() {
        fetch('get_gold_rate_data.php')
            .then(response => response.json())
            .then(data => {
                const ctx = document.getElementById('goldRateChart').getContext('2d');
                const chart = new Chart(ctx, {
                    type: 'line',
                    data: {
                        datasets: [{
                            label: 'Gold Rate (INR per 10 grams)',
                            data: data.dates.map((date, index) => ({
                                x: new Date(date),
                                y: data.prices[index]
                            })),
                            borderColor: 'rgba(255, 206, 86, 1)',
                            borderWidth: 2,
                            fill: false,
                            pointRadius: 6,
                            pointBackgroundColor: 'rgba(255, 206, 86, 1)',
                            pointBorderColor: '#000',
                            pointBorderWidth: 2,
                            pointHoverRadius: 6,
                            pointHoverBackgroundColor: 'rgba(255, 206, 86, 1)',
                            pointHoverBorderColor: '#000',
                            pointHoverBorderWidth: 2
                        }]
                    },
                    options: {
                        responsive: true,
                        plugins: {
                            datalabels: {
                                display: true,
                                color: '#444',
                                font: {
                                    weight: 'bold',
                                    size: 10
                                },
                                anchor: 'end',
                                align: 'top',
                                formatter: (value) => value.y.toLocaleString('en-IN', { style: 'currency', currency: 'INR' }),
                                offset: 6,
                                clamp: true,
                                clip: true,
                                padding: {
                                    top: 6,
                                    bottom: 6
                                },
                                listeners: {
                                    enter: context => {
                                        context.hovered = true;
                                        return true;
                                    },
                                    leave: context => {
                                        context.hovered = false;
                                        return true;
                                    }
                                },
                                adjust: {
                                    y: 10
                                },
                                // Prevent overlapping by hiding some labels if needed
                                display: function(context) {
                                    return context.dataset.data.length < 30 || context.dataIndex % Math.ceil(context.dataset.data.length / 30) === 0;
                                }
                            },
                            tooltip: {
                                callbacks: {
                                    label: function(context) {
                                        const date = context.raw.x.toLocaleDateString('en-IN', { year: 'numeric', month: 'short' });
                                        const price = context.raw.y.toLocaleString('en-IN', { style: 'currency', currency: 'INR' });
                                        return `${date}: ${price}`;
                                    }
                                }
                            },
                            legend: {
                                display: true
                            }
                        },
                        scales: {
                            x: {
                                type: 'time',
                                time: {
                                    unit: 'year',
                                    tooltipFormat: 'MMM yyyy'
                                },
                                title: {
                                    display: true,
                                    text: 'Year'
                                }
                            },
                            y: {
                                beginAtZero: false,
                                title: {
                                    display: true,
                                    text: 'Price (INR per 10 grams)'
                                }
                            }
                        }
                    },
                    plugins: [ChartDataLabels] // Ensure the datalabels plugin is used
                });
            })
            .catch(error => console.error('Error fetching data:', error));
    });
    </script>
    <div class="snackbars" id="form-output-global"></div>
    <script src="js/core.min.js"></script>
    <script src="js/script.js"></script>
</body>
</html>
